@@ -52,6 +52,8 @@ umask 022
 chmod 755 configure sh/* install-sh 2>/dev/null
 
 find . -depth -follow -type f | sed '
+/\/autoconf$/d
+/\/autoheader$/d
 /sio\/configure$/d
 /Strn\/configure$/d
 /\.o$/d
@@ -94,6 +96,7 @@ find . -depth -follow -type f | sed '
 /\/[Dd]ebug$/d
 /\/sio\/.*\//d
 /shit/d
+/dSYM/d
 /\/upload/d
 /\/config\.guess$/p
 /\/config\.sub$/p
