@@ -13,10 +13,10 @@ extern "C"
 {
 #endif	/* __cplusplus */
 
-#define kLibraryVersion "@(#) LibNcFTP 3.2.2 (August 8, 2008)"
+#define kLibraryVersion "@(#) LibNcFTP 3.2.2.2 (October 30, 2008)"
 
 /* This is used to verify validty of the data passed in. */
-#define kLibraryMagic "LibNcFTP 3.2.2"
+#define kLibraryMagic "LibNcFTP 3222"
 
 #if (defined(WIN32) || defined(_WINDOWS)) && !defined(__CYGWIN__)
 	/* Includes for Windows */
@@ -29,11 +29,15 @@ extern "C"
 #	pragma warning(disable : 4214)	// warning C4214: nonstandard extension used : bit field types other than int
 #	pragma warning(disable : 4115)	// warning C4115: 'IRpcStubBuffer' : named type definition in parentheses
 #	pragma warning(disable : 4711)	// warning C4711: function selected for automatic inline expansion
+	/* We now try for at least Windows 2000 compatibility (0x0500).
+	 * The code will still work on older systems, though.
+	 * Prior versions used 0x0400 instead.
+	 */
 #	ifndef WINVER
-#		define WINVER 0x0400
+#		define WINVER 0x0500
 #	endif
 #	ifndef _WIN32_WINNT
-#		define _WIN32_WINNT 0x0400
+#		define _WIN32_WINNT 0x0500
 #	endif
 #	ifndef _INC_WINDOWS
 #		include <windows.h>	/* includes <winsock2.h> if _WIN32_WINNT >= 0x400 */
@@ -165,14 +169,6 @@ extern "C"
 #	endif
 #else
 	/* Includes for UNIX */
-#	if (defined(__linux__)) && (! defined(_LARGEFILE64_SOURCE)) && (! defined(NO_LARGEFILE64_SOURCE))
-		/* Define _LARGEFILE64_SOURCE or NO_LARGEFILE64_SOURCE to
-		 * quiet this warning.  Be sure to define this for ALL
-		 * code that uses LibNcFTP.
-		 */
-#		warning "<ncftp.h> is #defining _LARGEFILE64_SOURCE for you"
-#		define _LARGEFILE64_SOURCE 1
-#	endif
 #	include <unistd.h>
 #	include <sys/types.h>
 #	include <sys/stat.h>
@@ -428,6 +424,7 @@ typedef struct FTPConnectionInfo {
 	 */
 	struct sockaddr_in clientKnownExternalAddr;	
 
+	struct sockaddr_in preferredLocalAddr;	/* You may modify this. */
 	int maxNumberOfSuccessivePASVAttempts;	/* You may modify this. */
 
 #if USE_SIO
@@ -1060,6 +1057,7 @@ int FTPFileExistsNlst(const FTPCIPtr cip, const char *const file);
 int FTPFileExists2(const FTPCIPtr cip, const char *const file, const int tryMDTM, const int trySIZE, const int tryMLST, const int trySTAT, const int tryNLST);
 
 void FTPGetDateStr(time_t t, const char *fmt, char *const ltstr1, const size_t ltstr1size, char *const gtstr1, const size_t gtstr1size);
+int BindToEphemeralPortNumber(const int sockfd, struct sockaddr_in *const addrp, const int ephemLo, const int ephemHi);
 int BufferGets(char *, size_t, int, char *, char **, char **, size_t);
 void DisposeFileInfoListContents(FTPFileInfoListPtr);
 void InitFileInfoList(FTPFileInfoListPtr);
